<div class="{{banner_class}}" style="display:flex; align-items:center; justify-content: space-between;">
  <div style="display:flex; align-items:center; overflow-wrap: anywhere;">
    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" style="height:2rem; width:2rem; color: #ffcc00; margin-left:0.5em; margin-right:0.5rem;">
      <path stroke-linecap="round" stroke-linejoin="round" d="M12 9v3.75m-9.303 3.376c-.866 1.5.217 3.374 1.948 3.374h14.71c1.73 0 2.813-1.874 1.948-3.374L13.949 3.378c-.866-1.5-3.032-1.5-3.898 0L2.697 16.126zM12 15.75h.007v.008H12v-.008z" />
    </svg>
    Please confirm your email address: {{email}}
  </div>
  <a href="{{link}}" class="{{link_class}}" target="_blank" style="display: flex; align-items: center; margin-left:1rem; margin-right:1rem; flex-shrink: 0">
    <img src="{{img}}" alt="mail provider icon" style="margin-right: 0.5em; width: 2rem;"\>
    Open Confirmation Email
  </a>
</div>